@@ -17,28 +17,36 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #ifndef __MT_COMMON_H__
 #define __MT_COMMON_H__
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
+#include <gsettings-desktop-schemas/gdesktop-enums.h>
+
+#include "mt-enum-types.h"
 
 G_BEGIN_DECLS
 
-#define MT_ICON_NAME  "input-mouse"
+#define MT_ICON_NAME                "input-mouse"
 
-#define MOUSETWEAKS_DBUS_NAME  "org.gnome.Mousetweaks"
-#define MOUSETWEAKS_DBUS_IFACE "org.gnome.Mousetweaks"
-#define MOUSETWEAKS_DBUS_PATH  "/org/gnome/Mousetweaks"
+#define MOUSETWEAKS_DBUS_NAME       "org.gnome.Mousetweaks"
+#define MOUSETWEAKS_DBUS_IFACE      "org.gnome.Mousetweaks"
+#define MOUSETWEAKS_DBUS_PATH       "/org/gnome/Mousetweaks"
 
 /* GSettings */
-#define MT_SCHEMA_ID                "org.gnome.mousetweaks"
+#define MOUSETWEAKS_SCHEMA_ID       "org.gnome.mousetweaks"
+#define KEY_CTW_STYLE               "click-type-window-style"
+#define KEY_CTW_ORIENTATION         "click-type-window-orientation"
+#define KEY_CTW_GEOMETRY            "click-type-window-geometry"
 
+#define A11Y_MOUSE_SCHEMA_ID        "org.gnome.desktop.a11y.mouse"
+#define KEY_DWELL_ENABLED           "dwell-click-enabled"
 #define KEY_DWELL_TIME              "dwell-time"
 #define KEY_DWELL_THRESHOLD         "dwell-threshold"
 #define KEY_DWELL_MODE              "dwell-mode"
@@ -46,46 +54,37 @@ G_BEGIN_DECLS
 #define KEY_DWELL_GESTURE_DOUBLE    "dwell-gesture-double"
 #define KEY_DWELL_GESTURE_DRAG      "dwell-gesture-drag"
 #define KEY_DWELL_GESTURE_SECONDARY "dwell-gesture-secondary"
-#define KEY_SSC_TIME                "ssc-time"
-#define KEY_CTW_VISIBLE             "ctw-visible"
-#define KEY_CTW_STYLE               "ctw-style"
-#define KEY_ANIMATE_CURSOR          "animate-cursor"
-
-#define GSD_MOUSE_SCHEMA_ID         "org.gnome.settings-daemon.peripherals.mouse"
-
-#define KEY_DWELL_ENABLED           "dwell-click-enabled"
 #define KEY_SSC_ENABLED             "secondary-click-enabled"
+#define KEY_SSC_TIME                "secondary-click-time"
+#define KEY_CTW_VISIBLE             "click-type-window-visible"
 
-enum
-{
-    DWELL_MODE_CTW = 0,
-    DWELL_MODE_GESTURE
-};
+#define N_CLICK_TYPES 4
 
 typedef enum
 {
-    DWELL_CLICK_TYPE_RIGHT = 0,
-    DWELL_CLICK_TYPE_DRAG,
-    DWELL_CLICK_TYPE_DOUBLE,
-    DWELL_CLICK_TYPE_SINGLE,
-    N_CLICK_TYPES
-} MtClickType;
-
-enum
-{
-    DIRECTION_LEFT = 0,
-    DIRECTION_RIGHT,
-    DIRECTION_UP,
-    DIRECTION_DOWN,
-    DIRECTION_DISABLE
-};
+    MT_DWELL_CLICK_TYPE_RIGHT,
+    MT_DWELL_CLICK_TYPE_DRAG,
+    MT_DWELL_CLICK_TYPE_DOUBLE,
+    MT_DWELL_CLICK_TYPE_SINGLE
+} MtDwellClickType;
 
 typedef enum
 {
-    MT_MESSAGE_ERROR = 0,
-    MT_MESSAGE_WARNING,
-    MT_MESSAGE_QUESTION,
-    MT_MESSAGE_LOGOUT
+    MT_CLICK_TYPE_WINDOW_STYLE_TEXT,
+    MT_CLICK_TYPE_WINDOW_STYLE_ICON,
+    MT_CLICK_TYPE_WINDOW_STYLE_BOTH
+} MtClickTypeWindowStyle;
+
+typedef enum
+{
+    MT_CLICK_TYPE_WINDOW_ORIENTATION_HORIZONTAL,
+    MT_CLICK_TYPE_WINDOW_ORIENTATION_VERTICAL
+} MtClickTypeWindowOrientation;
+
+typedef enum /*< skip >*/
+{
+    MT_MESSAGE_TYPE_ERROR,
+    MT_MESSAGE_TYPE_WARNING,
 } MtMessageType;
 
 Display *    mt_common_get_xdisplay      (void);
@@ -98,7 +97,7 @@ GdkScreen *  mt_common_get_screen        (void);
 void         mt_common_show_help         (GdkScreen     *screen,
                                           guint32        timestamp);
 
-gint         mt_common_show_dialog       (const gchar   *primary,
+void         mt_common_show_dialog       (const gchar   *primary,
                                           const gchar   *secondary,
                                           MtMessageType  type);
 
